@@ -558,7 +558,7 @@ _fill_link_struct_vars() {
     local str=''
 
     for str in $LINK_STRUCT; do
-        str=$(echo $str | tr -s [:blank:] | sed 's/^ *//g')
+        str=$(echo $str | tr -s "[:blank:]" | sed 's/^ *//g')
         local var_name=$(echo $str |  cut -d' ' -f3)
         local var_value=$(eval echo $str | cut -d' ' -f4)
         eval $var_name="$var_value"
@@ -568,7 +568,7 @@ _fill_link_struct_vars() {
 # Simple functions for working with LINK_STRUCT
 # - argument - string from LINK_STRUCT
 _is_rewritable_in_slave_mode() {
-    local str=$(echo $1 | tr -s [:blank:] | sed 's/^ *//g')
+    local str=$(echo $1 | tr -s "[:blank:]" | sed 's/^ *//g')
     REPLY=$(echo $str | cut -d' ' -f2)
     if [ -z $REPLY ]; then
         return 1
@@ -580,7 +580,7 @@ _is_rewritable_in_slave_mode() {
 # -----------------------------------------------------------------------------
 # - argument - string from LINK_STRUCT
 _get_dir_var() {
-    local str=$(echo $1 | tr -s [:blank:] | sed 's/^ *//g')
+    local str=$(echo $1 | tr -s "[:blank:]" | sed 's/^ *//g')
     REPLY=$(echo $str | cut -d' ' -f3)
     if [ -z $REPLY ]; then
         return 1
@@ -592,7 +592,7 @@ _get_dir_var() {
 # -----------------------------------------------------------------------------
 # - argument - string from LINK_STRUCT
 _get_dir_path() {
-    local str=$(echo $1 | tr -s [:blank:] | sed 's/^ *//g')
+    local str=$(echo $1 | tr -s "[:blank:]" | sed 's/^ *//g')
     REPLY=$(eval echo $str | cut -d' ' -f4)
     if [ -z $REPLY ]; then
         return 1
@@ -604,7 +604,7 @@ _get_dir_path() {
 # -----------------------------------------------------------------------------
 # - argument - string from LINK_STRUCT
 _get_link_point() {
-    local str=$(echo $1 | tr -s [:blank:] | sed 's/^ *//g')
+    local str=$(echo $1 | tr -s "[:blank:]" | sed 's/^ *//g')
     REPLY=$(echo $str | cut -d' ' -f5)
     if [ -z $REPLY ]; then
         return 1
@@ -616,7 +616,7 @@ _get_link_point() {
 # -----------------------------------------------------------------------------
 # - argument - string from LINK_STRUCT
 _is_dir() {
-    local str=$(echo $1 | tr -s [:blank:] | sed 's/^ *//g')
+    local str=$(echo $1 | tr -s "[:blank:]" | sed 's/^ *//g')
     if [ "x$(echo $str | cut -d' ' -f1)" = "xd" ]; then
         return 0
     else
@@ -776,7 +776,7 @@ IFS=";"
 
 # locally hardcoded for test purposes
 #DEFAULT_PACKAGEID="compilers_and_libraries_2019.0.001"
-DEFAULT_PACKAGEID="compilers_and_libraries_2019.2.187"
+DEFAULT_PACKAGEID="compilers_and_libraries_2019.4.243"
 
 PACKAGEID=$DEFAULT_PACKAGEID
 
