@@ -39,6 +39,7 @@
 #include "hpcg.hpp"
 
 #include "CG.hpp"
+#include "CG_ref.hpp"
 #include "mytimer.hpp"
 #include "ComputeSPMV.hpp"
 #include "ComputeSPMV_ref.hpp"
@@ -77,7 +78,9 @@
 int CG(const SparseMatrix & A, CGData & data, const Vector & b, Vector & x,
     const int max_iter, const double tolerance, int & niters, double & normr, double & normr0,
     double * times, bool doPreconditioning) {
-
+#ifdef HPCG_LOCAL_LONG_LONG
+    return CG_ref(A, data, b, x, max_iter, tolerance, niters, normr, normr0, times, doPreconditioning);
+#else
     double rtz = 0.0, oldrtz = 0.0, alpha = 0.0, beta = 0.0, pAp = 0.0, ff = 0.0;
 
     double t0 = 0.0, t1 = 0.0, t2 = 0.0, t3 = 0.0, t4 = 0.0, t5 = 0.0;
@@ -259,6 +262,6 @@ int CG(const SparseMatrix & A, CGData & data, const Vector & b, Vector & x,
     times[5] += t5; // preconditioner apply time
 
     delete (MPI_Request *)request;
-
+#endif
     return 0;
 }
