@@ -35,6 +35,10 @@
 #include <mpi.h>
 #endif
 
+#include <limits.h>
+#include <fstream>
+#include "hpcg.hpp"
+
 #ifndef HPCG_NO_OPENMP
 #include <omp.h>
 #endif
@@ -62,7 +66,7 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
   // specific nature of the sparsity pattern may not be explicitly used.
   // Make local copies of geometry information.  Use global_int_t since the RHS products in the calculations
   // below may result in global range values.
-#if 0
+#ifdef HPCG_LOCAL_LONG_LONG
   GenerateProblem_ref(A,b,x,xexact);
 #else
   // Make local copies of geometry information.  Use global_int_t since the RHS products in the calculations
@@ -109,9 +113,39 @@ void GenerateProblem(SparseMatrix & A, Vector * b, Vector * x, Vector * xexact)
   int nproc = A.nproc;
   A.localToGlobalMap.resize(localNumberOfRows);
   // Now allocate the arrays pointed to
-  A.mtxL = (local_int_t*) MKL_malloc(sizeof(local_int_t )*numberOfNonzerosPerRow*localNumberOfRows, ALIGN );
-  A.mtxG = (global_int_t*)MKL_malloc(sizeof(global_int_t)*numberOfNonzerosPerRow*localNumberOfRows, ALIGN );
-  A.mtxA = (double*)      MKL_malloc(sizeof(double      )*numberOfNonzerosPerRow*localNumberOfRows, ALIGN );
+  local_int_t nnz = numberOfNonzerosPerRow*localNumberOfRows;
+  global_int_t nnz_gl = ((global_int_t)numberOfNonzerosPerRow)*((global_int_t)localNumberOfRows);
+
+  int local_flag = 1;
+  if (nnz_gl > INT_MAX)
+    local_flag = 0;
+  int global_flag = local_flag;
+#ifndef HPCG_NO_MPI
+  MPI_Barrier(MPI_COMM_WORLD);
+  MPI_Allreduce(&local_flag, &global_flag, 1, MPI_INT, MPI_LAND, MPI_COMM_WORLD);
+#endif
+  if (global_flag == 0)
+  {
+    if (A.geom->rank == 0) {
+      HPCG_fout << "Error: one of the processes has overflowed local number of nonzeros.\n" 
+                << "The size of the problem is too large.\nRe-build HPCG with the flag -DHPCG_ILP64 in order to use long long \n"
+                << "int as the local integer type.\n"
+                << "Warning: For such sizes, non-optimized HPCG implementation will be used.\n";
+      HPCG_fout.flush();
+    }
+#ifndef HPCG_NO_MPI
+    MPI_Barrier(MPI_COMM_WORLD);
+#endif
+    HPCG_Finalize();
+#ifndef HPCG_NO_MPI
+    MPI_Finalize();
+#endif
+    exit(-1);
+  }
+
+  A.mtxL = (local_int_t*) MKL_malloc(sizeof(local_int_t )*nnz, ALIGN );
+  A.mtxG = (global_int_t*)MKL_malloc(sizeof(global_int_t)*nnz, ALIGN );
+  A.mtxA = (double*)      MKL_malloc(sizeof(double      )*nnz, ALIGN );
 
   A.boundaryRows = (local_int_t*) MKL_malloc( sizeof(local_int_t)*(nx*ny*nz - (nx-2)*(ny-2)*(nz-2)), ALIGN);
 
