@@ -39,8 +39,12 @@
 
   Define as "long long" when local problem dimension is > 2^31
 */
+
+#ifdef HPCG_LOCAL_LONG_LONG
+typedef long long local_int_t;
+#else
 typedef int local_int_t;
-//typedef long long local_int_t;
+#endif
 
 /*!
   This defines the type for integers that have global dimension
