@@ -55,6 +55,7 @@
 
 void SetupHalo(SparseMatrix & A)
 {
+#ifndef HPCG_LOCAL_LONG_LONG
     if( A.geom->size > 1 )
     {
         local_int_t localNumberOfRows = A.localNumberOfRows;
@@ -69,7 +70,8 @@ void SetupHalo(SparseMatrix & A)
         local_int_t totalToBeSent = 0, totalToBeReceived = 0, cnt = 0;
         local_int_t number_of_neighbors = A.numberOfSendNeighbors;
         local_int_t *receiveLength = NULL, *sendLength = NULL, *map_neib_s = NULL;
-        local_int_t *map_neib_r = A.work, *neighbors = NULL;
+        local_int_t *map_neib_r = A.work;
+        int *neighbors = NULL;
         global_int_t *map_send = NULL;
 
         double *sendBuffer = NULL;
@@ -80,7 +82,7 @@ void SetupHalo(SparseMatrix & A)
 
         map_send      = (global_int_t*) MKL_malloc( sizeof(global_int_t)*A.numOfBoundaryRows*number_of_neighbors, 512 );
         map_neib_s    = (local_int_t *) MKL_malloc( sizeof(local_int_t )*A.geom->size                           , 512 );
-        neighbors     = (local_int_t *) MKL_malloc( sizeof(local_int_t )*number_of_neighbors                    , 512 );
+        neighbors     = (int*         ) MKL_malloc( sizeof(int         )*number_of_neighbors                    , 512 );
         receiveLength = (local_int_t *) MKL_malloc( sizeof(local_int_t )*number_of_neighbors                    , 512 );
         sendLength    = (local_int_t *) MKL_malloc( sizeof(local_int_t )*number_of_neighbors                    , 512 );
 
@@ -278,4 +280,7 @@ void SetupHalo(SparseMatrix & A)
         A.totalToBeSent = 0;
         A.elementsToSend = 0;
     }
+#else
+    SetupHalo_ref(A);
+#endif
 }
