@@ -163,7 +163,7 @@ inline void InitializeSparseMatrix(SparseMatrix & A, Geometry * geom) {
   @param[inout] diagonal  Vector of diagonal values (must be allocated before call to this function).
  */
 inline void CopyMatrixDiagonal(SparseMatrix & A, Vector & diagonal) {
-#if 1
+#ifndef HPCG_LOCAL_LONG_LONG
     SparseMatrix *Ac = &A;
     struct optData *optData = (struct optData *)Ac->optimizationData;
     double * dv = diagonal.values;
@@ -209,19 +209,40 @@ inline void ReplaceMKLMatrixDiagonal(SparseMatrix & A, Vector & diagonal)
   @param[in] A the known system matrix
  */
 inline void DeleteMatrix(SparseMatrix & A) {
+
+#ifdef HPCG_LOCAL_LONG_LONG
+  for (local_int_t i = 0; i< A.localNumberOfRows; ++i) {
+    delete [] A.matrixValues[i];
+    delete [] A.mtxIndG[i];
+    delete [] A.mtxIndL[i];
+  }
+
+  if (A.title)                  delete [] A.title;
+  if (A.nonzerosInRow)          delete [] A.nonzerosInRow;
+  if (A.mtxIndG)                delete [] A.mtxIndG;
+  if (A.mtxIndL)                delete [] A.mtxIndL;
+  if (A.matrixValues)           delete [] A.matrixValues;
+  if (A.matrixDiagonal)         delete [] A.matrixDiagonal;
+
+#ifndef HPCG_NO_MPI
+  if (A.elementsToSend)         delete [] A.elementsToSend;
+  if (A.neighbors)              delete [] A.neighbors;
+  if (A.receiveLength)          delete [] A.receiveLength;
+  if (A.sendLength)             delete [] A.sendLength;
+  if (A.sendBuffer)             delete [] A.sendBuffer;
+#endif
+
+  if (A.geom!=0) { delete A.geom; A.geom = 0;}
+  if (A.Ac!=0) { DeleteMatrix(*A.Ac); delete A.Ac; A.Ac = 0;} // Delete coarse matrix
+  if (A.mgData!=0) { DeleteMGData(*A.mgData); delete A.mgData; A.mgData = 0;} // Delete MG data
+
+#else
   if (A.title)                  delete [] A.title;
   if (A.nonzerosInRow) { MKL_free(A.nonzerosInRow); A.nonzerosInRow  = NULL; }
   if (A.matrixDiagonal){ MKL_free(A.matrixDiagonal);A.matrixDiagonal = NULL; }
   if (A.boundaryRows)  { MKL_free( A.boundaryRows) ;A.boundaryRows   = NULL; }
 
 #ifndef HPCG_NO_MPI
-  /*
-  if (A.elementsToSend)       delete [] A.elementsToSend;
-  if (A.neighbors)              delete [] A.neighbors;
-  if (A.receiveLength)            delete [] A.receiveLength;
-  if (A.sendLength)            delete [] A.sendLength;
-  if (A.sendBuffer)            delete [] A.sendBuffer;
-  */
   MKL_free(A.elementsToSend);
   MKL_free(A.neighbors);
   MKL_free(A.receiveLength);
@@ -246,6 +267,7 @@ inline void DeleteMatrix(SparseMatrix & A) {
   if (A.geom!=0) { delete A.geom; A.geom = 0;}
   if (A.Ac!=0) { DeleteMatrix(*A.Ac); delete A.Ac; A.Ac = 0;} // Delete coarse matrix
   if (A.mgData!=0) { DeleteMGData(*A.mgData); delete A.mgData; A.mgData = 0;} // Delete MG data
+#endif
   return;
 }
 
