@@ -256,7 +256,7 @@ MODULE MKL_SPBLAS
 
 !   compressed sparse column format (4-arrays version),
 !   SPARSE_MATRIX_TYPE_GENERAL by default, pointers to input arrays are stored in the handle
-        FUNCTION MKL_SPARSE_S_CREATE_CSC(A,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_S_CREATE_CSC(A,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_S_CREATE_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT
             IMPORT SPARSE_MATRIX_T
@@ -264,13 +264,13 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(IN) :: indexing
             INTEGER, INTENT(IN) :: rows
             INTEGER, INTENT(IN) :: cols
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(IN), DIMENSION(*) :: col_indx
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_start
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_end
+            INTEGER, INTENT(IN), DIMENSION(*) :: row_indx
             REAL(C_FLOAT), INTENT(IN), DIMENSION(*) :: values
             INTEGER(C_INT) MKL_SPARSE_S_CREATE_CSC
         END FUNCTION
-        FUNCTION MKL_SPARSE_D_CREATE_CSC(A,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_D_CREATE_CSC(A,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_D_CREATE_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE
             IMPORT SPARSE_MATRIX_T
@@ -278,13 +278,13 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(IN) :: indexing
             INTEGER, INTENT(IN) :: rows
             INTEGER, INTENT(IN) :: cols
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(IN), DIMENSION(*) :: col_indx
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_start
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_end
+            INTEGER, INTENT(IN), DIMENSION(*) :: row_indx
             REAL(C_DOUBLE), INTENT(IN), DIMENSION(*) :: values
             INTEGER(C_INT) MKL_SPARSE_D_CREATE_CSC
         END FUNCTION
-        FUNCTION MKL_SPARSE_C_CREATE_CSC(A,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_C_CREATE_CSC(A,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_C_CREATE_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX
             IMPORT SPARSE_MATRIX_T
@@ -292,13 +292,13 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(IN) :: indexing
             INTEGER, INTENT(IN) :: rows
             INTEGER, INTENT(IN) :: cols
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(IN), DIMENSION(*) :: col_indx
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_start
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_end
+            INTEGER, INTENT(IN), DIMENSION(*) :: row_indx
             COMPLEX(C_FLOAT_COMPLEX), INTENT(IN), DIMENSION(*) :: values
             INTEGER(C_INT) MKL_SPARSE_C_CREATE_CSC
         END FUNCTION
-        FUNCTION MKL_SPARSE_Z_CREATE_CSC(A,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_Z_CREATE_CSC(A,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_Z_CREATE_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX
             IMPORT SPARSE_MATRIX_T
@@ -306,9 +306,9 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(IN) :: indexing
             INTEGER, INTENT(IN) :: rows
             INTEGER, INTENT(IN) :: cols
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_start
-            INTEGER, INTENT(IN), DIMENSION(*) :: rows_end
-            INTEGER, INTENT(IN), DIMENSION(*) :: col_indx
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_start
+            INTEGER, INTENT(IN), DIMENSION(*) :: cols_end
+            INTEGER, INTENT(IN), DIMENSION(*) :: row_indx
             COMPLEX(C_DOUBLE_COMPLEX), INTENT(IN), DIMENSION(*) :: values
             INTEGER(C_INT) MKL_SPARSE_Z_CREATE_CSC
         END FUNCTION
@@ -567,7 +567,7 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT) MKL_SPARSE_Z_EXPORT_CSR
         END FUNCTION
 
-        FUNCTION MKL_SPARSE_S_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_S_EXPORT_CSC(source,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_S_EXPORT_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT, C_PTR
             IMPORT SPARSE_MATRIX_T
@@ -575,13 +575,13 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(INOUT) :: indexing
             INTEGER       , INTENT(INOUT) :: rows
             INTEGER       , INTENT(INOUT) :: cols
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
-            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: row_indx
             TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_S_EXPORT_CSC
         END FUNCTION
-        FUNCTION MKL_SPARSE_D_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_D_EXPORT_CSC(source,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_D_EXPORT_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE, C_PTR
             IMPORT SPARSE_MATRIX_T
@@ -589,13 +589,13 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(INOUT) :: indexing
             INTEGER       , INTENT(INOUT) :: rows
             INTEGER       , INTENT(INOUT) :: cols
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
-            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: row_indx
             TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_D_EXPORT_CSC
         END FUNCTION
-        FUNCTION MKL_SPARSE_C_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_C_EXPORT_CSC(source,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_C_EXPORT_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_FLOAT_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
@@ -603,13 +603,13 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(INOUT) :: indexing
             INTEGER       , INTENT(INOUT) :: rows
             INTEGER       , INTENT(INOUT) :: cols
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
-            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: row_indx
             TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_C_EXPORT_CSC
         END FUNCTION
-        FUNCTION MKL_SPARSE_Z_EXPORT_CSC(source,indexing,rows,cols,rows_start,rows_end,col_indx,values) &
+        FUNCTION MKL_SPARSE_Z_EXPORT_CSC(source,indexing,rows,cols,cols_start,cols_end,row_indx,values) &
                  BIND(C, name='MKL_SPARSE_Z_EXPORT_CSC')
             USE, INTRINSIC :: ISO_C_BINDING , ONLY : C_INT, C_DOUBLE_COMPLEX, C_PTR
             IMPORT SPARSE_MATRIX_T
@@ -617,9 +617,9 @@ MODULE MKL_SPBLAS
             INTEGER(C_INT), INTENT(INOUT) :: indexing
             INTEGER       , INTENT(INOUT) :: rows
             INTEGER       , INTENT(INOUT) :: cols
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_start
-            TYPE(C_PTR)   , INTENT(INOUT) :: rows_end
-            TYPE(C_PTR)   , INTENT(INOUT) :: col_indx
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_start
+            TYPE(C_PTR)   , INTENT(INOUT) :: cols_end
+            TYPE(C_PTR)   , INTENT(INOUT) :: row_indx
             TYPE(C_PTR)   , INTENT(INOUT) :: values
             INTEGER(C_INT) MKL_SPARSE_Z_EXPORT_CSC
         END FUNCTION
