@@ -149,6 +149,14 @@ _Mkl_Api(int,vsRngBeta,(const MKL_INT  , VSLStreamStatePtr  , const MKL_INT  , f
 _MKL_API(int,VSRNGBETA,(const MKL_INT *, VSLStreamStatePtr *, const MKL_INT *, float [],  const float *,  const float *,  const float *,  const float * ))
 _mkl_api(int,vsrngbeta,(const MKL_INT *, VSLStreamStatePtr *, const MKL_INT *, float [],  const float *,  const float *,  const float *,  const float * ))
 
+/* Chi-square distribution */
+_Mkl_Api(int,vdRngChiSquare,(const MKL_INT  , VSLStreamStatePtr  , const MKL_INT  , double [], const int  ))
+_MKL_API(int,VDRNGCHISQUARE,(const MKL_INT *, VSLStreamStatePtr *, const MKL_INT *, double [], const int *))
+_mkl_api(int,vdrngchisquare,(const MKL_INT *, VSLStreamStatePtr *, const MKL_INT *, double [], const int *))
+_Mkl_Api(int,vsRngChiSquare,(const MKL_INT  , VSLStreamStatePtr  , const MKL_INT  , float [],  const int  ))
+_MKL_API(int,VSRNGCHISQUARE,(const MKL_INT *, VSLStreamStatePtr *, const MKL_INT *, float [],  const int *))
+_mkl_api(int,vsrngchisquare,(const MKL_INT *, VSLStreamStatePtr *, const MKL_INT *, float [],  const int *))
+
 /*
 //++
 //  VSL DISCRETE DISTRIBUTION GENERATOR FUNCTION DECLARATIONS.
